/******************************************************************************

	FILE				: main.c

	AUTHOR			: Axiom Manufacturing

	PURPOSE			: Demo application code for DEMO9S08SV16/FL16 board

 ******************************************************************************

	Operation:

	Ensure shunts are set to default position.  Connect USB cable to the USB
	connector.  Connect serial cable to COM connector.  Open terminal program
	and configure for 9600,8,N,1
	
	Press SW1 to enable / disable Buzzer at approx 2300 Hz
	Press SW2 to enable / disable flashing LEDs.  Rotate POT to vary blink rate
	Terminal input is echoed (ensure terminal Local Echo is disabled)
	Reset push-button is enabled
	
******************************************************************************/
#include <hidef.h>				// for EnableInterrupts macro
#include "derivative.h"			// include peripheral declarations
#include "sci_08.h"				// SCI perihperal declarations


#define	ON		1
#define	OFF	0

#define	LED1	PTBD_PTBD2
#define	LED2	PTBD_PTBD3
#define	SW1	PTAD_PTAD2
#define	SW2	PTAD_PTAD3


void ICS_init(void);				// init ICS module
void PIO_init(void);				// init IO ports
void TPM1_init(void);			// init TPM1 module
void TPM2_init(void);			// init TPM2 module
void ADC_init(void);				// init ADC module

void main(void) {

	EnableInterrupts;				// enable interrupts
	SOPT1 = 0x03;					// disable COP, bgnd pin active, reset pin active
	
	ICS_init();						// init ICS module
	PIO_init();						// init PIO module
	TPM1_init();					// init TPM1 module
	TPM2_init();					// init TPM2 module
	ADC_init();						// init ADC module

	ensci();							// Enable SCI module
	
	for(;;) {

		byte sbyte;
		
		if(SW1 == 0){
			while (SW1 == 0);		// wait for PBSW release
			TPM1SC_CLKSx ^= 1;	// toggle TPM1 clock on/off
		}
		else if(SW2 == 0){
			while (SW2 == 0);		// wait for PBSW release
			TPM2SC_CLKSx ^= 1;	// toggle TPM2 on/off
		}

		sbyte = GetSByte();	// get input char
		
		if(sbyte > 0){
			putch(sbyte);		// send char to terminal
			sbyte = 0;		
		}
	}
}


void ICS_init(void){
	if(NVICSTRM == 0xFF)			// If programmed trim value is blank
		ICSTRM = 0x80;				// load default value
	else
		ICSTRM = NVICSTRM;		// else load programmed trim value
}

void TPM1_init(void){
//	TPM1SC_TOIE = 1;				// enable TPM1 interrupt
	TPM1SC_CLKSx = 0;				// disable timer
	TPM1SC_PS = 4;					// input clk div 64
	TPM1MOD = 0x18;				// modulus
	TPM1C0SC = 0x14;				// toggle output on compare
//	TPM1SC_CLKSx = 1;				// start timer at bus clk rate
}

void TPM2_init(void){
	TPM2SC_TOIE = 1;				// enable TPM2 interrupt
	TPM2SC_CLKSx = 0;				// disable timer
	TPM2SC_PS = 4;					// input clk div 64
//	TPM2MOD = 0xFFFF;				// modulus
	TPM2C0SC_ELS0x = 0x0;		// pin is gpio
//	TPM2SC_CLKSx = 1;				// start timer at bus clk rate
}

void PIO_init(void){
	PTADD = 0x00;					// PTA[5:0] input
	PTAPE = 0x0C;					// PTA[3:2] pull-ups enabled

	PTBD = 0x08;
	PTBDD = 0x0C;					// PTB[3:2] output
	
}

void ADC_init(void){

	ADCCFG = 0x00;					// input clk div 1, 8 bit result, bus clk input
	ADCSC2 = 0x00;					// SW trigger, compare function disabled
	APCTL1 = 0x01;					// disable IO control for ADP1 input
	ADCSC1 = 0x21;					// continuous conversion, ADC CH1
}

//void interrupt 13 Tpm1OvfIsr(void){
//	TPM1SC_TOF = 0;				// clear TOF
//	LED1 ^= 1;						// toggle LED1
//	LED2 ^= 1;						// toggle LED2
//}

void interrupt 16 Tpm1OvfIsr(void){
	word state;
	TPM2SC_CLKSx = 0;				// stop TPM2
	LED1 ^= 1;						// toggle LED1
	LED2 ^= 1;						// toggle LED2
	while(!ADCSC1_COCO);			// wait for ADC conversion to complete
	state = (ADCRL << 8);		// get ADC result & shift to high byte
	state |= 0x00FF;				// init low byte 
	TPM2MOD = state;				// load new modulus
	TPM2SC_TOF = 0;				// clear TOF
	TPM2SC_CLKSx = 1;				// start TPM2
	
}

